This directory is a vendored copy of several files from Sei Lisa's
https://github.com/Sei-Lisa/LSL-PyOptimizer.

The only changes to the files are to the import lines to make all imports
relative to the current directory, since LSL-PyOptimizer proper isn't packaged.
